\version "2.14.2"

\header {
  texidoc = "
Prior to version 2.11.44, Lilypond's \\parenthesize function (to put
parentheses around notes, articulations, etc.) only worked on notes if
they were written inside a chord. In particular, \\parenthesize c4
would not work, only <\\parenthesize c>4 will. Similarly, trying to
parenthesize a rest would fail.


As of version 2.11.44, the \\parenthesize function has been redefined
to set the parenthesize property of a music expression to ##t, so that
if applied to a chord, it will set this property for all note and rest
children of a chord. This immediately solves the problem of
parenthesizing rests, as well as allowing the parenthesizing of all
notes inside a chord at once. All other uses of \\parenthesize continue
working as usual.  This snippet shows how to redefine the
\\parenthesize function when using an older version, to make the
following commands work as expected:


\\parenthesize c4-. \\parenthesize r4 \\parenthesize <c e g>4->



"
  doctitle = "Redefining \\parenthesize to work with single notes, rests and whole chords"
}
parenthesize =
#(define-music-function (parser loc arg) (ly:music?)
   "Tag @var{arg} to be parenthesized."
   (if (memq 'event-chord (ly:music-property arg 'types)) 
     ; arg is an EventChord -> set the parenthesize property on all child notes and rests
     (map 
       (lambda (ev) 
         (if (or (memq 'note-event (ly:music-property ev 'types))
           (memq 'rest-event (ly:music-property ev 'types)))
           (set! (ly:music-property ev 'parenthesize) #t)
         )
       )
       (ly:music-property arg 'elements))
     ; No chord, simply set property for this expression:
     (set! (ly:music-property arg 'parenthesize) #t)
   )
   arg)


\relative c'' {

  % parentheses on single notes (with articulations), inside chord and articulation
  \parenthesize c \parenthesize c-. <\parenthesize c> c-\parenthesize-. |

  % parenthesized rests and whole chords
  \parenthesize <c e g>4-> \parenthesize r \parenthesize r2^"rest" |

  % parenthesizing dynamics and text markup
  c4-\parenthesize\p c-\parenthesize-"Text" \parenthesize c\p r4 |

  % parenthesizing other music expressions does nothing
  \parenthesize {c4 c-. <c e g> r} |
}

